@@ -1,13 +1,18 @@
 package Image::Info::BMP;
-$VERSION = '1.02';
+$VERSION = '1.04';
 use strict;
 
+use constant _CAN_LITTLE_ENDIAN_PACK => $] >= 5.009002;
+
 sub process_file {
     my($info, $source, $opts) = @_;
     my(@comments, @warnings, @header, %info, $buf, $total);
 
     read($source, $buf, 54) == 54 or die "Can't reread BMP header: $!";
-    @header = unpack("vVv2V2V2v2V2V2V2", $buf);
+    @header = unpack((_CAN_LITTLE_ENDIAN_PACK
+		      ? "vVv2V2Vl<v2V2V2V2"
+		      : "vVv2V2V2v2V2V2V2"
+		     ), $buf);
     $total += length($buf);
 
     if( $header[9] && $header[9] < 24 ){
@@ -23,7 +28,11 @@ sub process_file {
     else{
 	$info->push_info(0, "file_ext" => "bmp"); # || dib
     }
-    $info->push_info(0, "height", abs($header[7]));
+
+    $info->push_info(0, "height", (_CAN_LITTLE_ENDIAN_PACK
+				   ? abs($header[7])
+				   : ($header[7] >= 2**31 ? 2**32 - $header[7] : $header[7])
+				  ));
     $info->push_info(0, "resolution", "$header[12]/$header[13]");
     $info->push_info(0, "width", $header[6]);
     $info->push_info(0, "BitsPerSample" => $header[9]);
@@ -41,7 +50,7 @@ sub process_file {
 					'JPEG',		#V5
 					'PNG',		#V5
 					]->[$header[10]]);
-    #Version 5 Header ammendements
+    #Version 5 Header amendments
     # XXX Discard for now, need a test image
     if( $header[5] > 40 ){
 	read($source, $buf, $header[5]-40);  # XXX test
@@ -93,7 +102,7 @@ __END__
 
 =head1 NAME
 
-Image::Info::BMP - Windows Device Indepdent Bitmap support for Image::Info
+Image::Info::BMP - Windows Device Independent Bitmap support for Image::Info
 
 =head1 SYNOPSIS
 
@@ -109,7 +118,7 @@ Image::Info::BMP - Windows Device Indepdent Bitmap support for Image::Info
 
 =head1 DESCRIPTION
 
-This modules supplies the standard key names
+This module supplies the standard key names
 except for Gamma, Interlace, LastModificationTime, as well as:
 
 =over
@@ -122,8 +131,8 @@ displaying the bitmap. If this value is zero, all colors are required.
 =item BMP_Origin
 
 If true the bitmap is a bottom-up DIB and its origin is the lower-left corner.
-Otherwise,
-the bitmap is a top-down DIB and its origin is the upper-left corner. 
+Otherwise, the bitmap is a top-down DIB and its origin is the upper-left 
+corner. 
 
 =item ColorPalette
 
@@ -135,7 +144,7 @@ as C<image_info($file, ColorPalette=E<gt>1)>.
 
 The number of colors the image uses.
 If 0 then this is a true color image.
-The number of color I<available> is 2 ^ B<BitsPerSample>.
+The number of colors I<available> is 2 ^ B<BitsPerSample>.
 
 =back
 
@@ -181,14 +190,14 @@ Random notes:
 
 =item Size mismatch
 
-The image may be correct, the filesize does not match the internally stored
+The image may be correct, but the filesize does not match the internally stored
 value.
 
 =back
 
 =head1 BUGS
 
-The current implementation only function on little-endian architectures.
+The current implementation only functions on little-endian architectures.
 Consequently erroneous data concerning compression (including
 B<file_ext> and B<file_mime_type>) may be reported.
 
